@@ -23,8 +23,9 @@ filter.grouped_eventlog <- function(.data, ...) {
 	groups <- groups(.data)
 	mapping <- mapping(.data)
 	.data %>%
-		as.data.frame() %>%
-		dplyr::filter(...) %>%
+		nest() %>%
+		mutate(data = map(data, dplyr::filter, ...)) %>%
+		unnest() %>%
 		re_map(mapping) %>%
 		group_by_at(vars(one_of(paste(groups))))
 
