@@ -2,6 +2,7 @@
 #' @description Generic summary function for eventlog class
 #' @param object Eventlog object
 #' @param ... Additional Arguments
+#' @rdname summary
 #' @method summary eventlog
 #' @export
 
@@ -9,7 +10,7 @@ summary.eventlog <- function(object, ...){
 
 	eventlog <- object
 
-	ca <- cases_light(eventlog)
+	ca <- case_list(eventlog)
 
 	number_of_events <- nrow(eventlog)
 	number_of_cases <- nrow(ca)
@@ -17,10 +18,8 @@ summary.eventlog <- function(object, ...){
 	number_of_activities <- nrow(activities(eventlog))
 
 
-	colnames(eventlog)[colnames(eventlog)==timestamp(eventlog)] <- "timestamp_classifier"
-
-	first_event <- as.character(arrange(eventlog, timestamp_classifier)$timestamp_classifier[1])
-	last_event <- as.character(arrange(eventlog, timestamp_classifier)$timestamp_classifier[nrow(eventlog)])
+	first_event <- as.character(min(pull(eventlog, !!as.symbol(timestamp(eventlog)))))
+	last_event <- as.character(max(pull(eventlog, !!as.symbol(timestamp(eventlog)))))
 
 	events_per_case <- number_of_events/number_of_cases
 
@@ -42,3 +41,11 @@ summary.eventlog <- function(object, ...){
 	NextMethod(object)
 
 }
+
+#' @describeIn summary Summary of grouped event log
+#' @export
+
+summary.grouped_eventlog <- function(object, ...) {
+	object <- eventlog(object)
+	NextMethod(object)
+}
